<?php
/**
 * Plugin Name: Softech Wp Clock
 * Plugin URI: https://wordpress.org/plugins/softech-wp-clock/
 * Description: Display a Time zone clock on your page/post set to your city's timezone. Choice of clocks, colors and sizes.
 * Version: 1.0.0
 * Author:      Softechure
 * Author URI:  https://softechure.com/
 * Text Domain: softech-wp-clock
 * Domain Path: /languages
 * License:     GPLv2
 
 Softech Wp Clock is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 2 of the License, or
 any later version.
 
 Softech Wp Clock is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with Softech Wp Clock. If not, see {License URI}.
*/


define( 'SOFTECH_WP_CLOCK_VERSION', '1.0.0' );
define( 'SOFTECH_WP_CLOCK_MINIMUM_WP_VERSION', '4.0' );
define( 'SOFTECH_WP_CLOCK_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );


if ( ! version_compare( PHP_VERSION, '5.4', '>=' ) ) 
{
  add_action( 'admin_notices', 'softech_wp_clock_fail_php_version' );
} 
elseif ( ! version_compare( get_bloginfo( 'version' ), '4.0', '>=' ) ) 
{
    add_action( 'admin_notices', 'softech_wp_clock_fail_wp_version' );
} 
else 
{
    require( dirname(__FILE__). '/plugin.php' );
}

/**
 * Softech Wp Clock admin notice for minimum PHP version.
 * Warning when the site doesn't have the minimum required PHP version.
 */
function softech_wp_clock_fail_php_version() 
{
    /* translators: %s: PHP version */
    $message = sprintf( esc_html__( 'Softech Wp Clock requires PHP version %s+, plugin is currently NOT RUNNING.', 'softech-wp-clock' ), '5.4' );
    $html_message = sprintf( '<div class="error">%s</div>', wpautop( $message ) );
    echo wp_kses_post( $html_message );
}

/**
 * Softech Wp Clock admin notice for minimum WordPress version.
 * Warning when the site doesn't have the minimum required WordPress version.
 */
function softech_wp_clock_fail_wp_version() 
{
    /* translators: %s: WordPress version */
    $message = sprintf( esc_html__( 'Softech Wp Clock requires WordPress version %s+. Because you are using an earlier version, the plugin is currently NOT RUNNING.', 'softech-wp-clock' ), '4.6' );
    $html_message = sprintf( '<div class="error">%s</div>', wpautop( $message ) );
    echo wp_kses_post( $html_message );
}

?>